Package: hash
Type: Package
Title: Full Featured Implementation of Hash Tables/Associative
        Arrays/Dictionaries
Version: 2.2.6.4
Date: 2026-01-21
Authors@R: c(person("Christopher", "Brown", email = "chris.brown@decisionpatterns.com", role = "aut"),
             person("John", "Hughes", email = "drjphughesjr@gmail.com", role = c("cre", "ctb")))
Depends: R (>= 2.12.0), methods, utils
Suggests: testthat, rbenchmark
Description: Implements a data structure similar to hashes in Perl and dictionaries in Python but with a purposefully R flavor. For objects of appreciable size, access using hashes outperforms native named lists and vectors.
License: GPL (>= 2)
URL: http://www.johnhughes.org
NeedsCompilation: no
Packaged: 2026-01-21 14:15:51 UTC; johnhughes
Author: Christopher Brown [aut],
  John Hughes [cre, ctb]
Maintainer: John Hughes <drjphughesjr@gmail.com>
Repository: CRAN
Date/Publication: 2026-01-21 15:00:09 UTC
Built: R 4.6.0; ; 2026-04-26 10:59:12 UTC; unix
